==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Members_List/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Link");
define("_EMAIL","Email");
define("_REALNAME","Nome Verdadeiro");
define("_FUNCTIONS","Funes");
define("_PREVIOUS","Pgina Anterior");
define("_MEMBERSLIST","Lista de Usurios");
define("_GREETINGS","Saudaes ao nosso mais novo usurio:");
define("_SORTBY","Selecionar por:");
define("_MNICKNAME","Apelido");
define("_MREALNAME","Nome Verdadeiro");
define("_MEMAIL","Email");
define("_MURL","Home-Page");
define("_ONLINEREG","Usurios registrados conectados atualmente:");
define("_WEHAVE","Ns temos");
define("_MREGISTERED","alguns usurios registrado. E destes");
define("_MREGONLINE","os seguinte(s) esto conectados agora.");
define("_REGSOFAR","usurios registrados at agora.");
define("_USERSFOUND","usurios encontrados por");
define("_USERSSHOWN","mostrar usurios");
define("_NOMEMBERS","Nenhum usurio encontrado por");
define("_PAGES","Pginas");
define("_HOMEPAGE","Home-Page");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Members_List/language/lang-brazilian.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Link");
define("_EMAIL","Email");
define("_REALNAME","Nome Verdadeiro");
define("_FUNCTIONS","Funes");
define("_PREVIOUS","Pgina Anterior");
define("_MEMBERSLIST","Lista de Usurios");
define("_GREETINGS","Saudaes ao nosso mais novo usurio:");
define("_SORTBY","Selecionar por:");
define("_MNICKNAME","Apelido");
define("_MREALNAME","Nome Verdadeiro");
define("_MEMAIL","Email");
define("_MURL","Home-Page");
define("_ONLINEREG","Usurios registrados conectados atualmente:");
define("_WEHAVE","Ns temos");
define("_MREGISTERED","alguns usurios registrado. E destes");
define("_MREGONLINE","os seguinte(s) esto conectados agora.");
define("_REGSOFAR","usurios registrados at agora.");
define("_USERSFOUND","usurios encontrados por");
define("_USERSSHOWN","mostrar usurios");
define("_NOMEMBERS","Nenhum usurio encontrado por");
define("_PAGES","Pginas");
define("_HOMEPAGE","Home-Page");

?>
